@@ -37,6 +37,7 @@
 #define GET_SETTINGS "getSettings"
 #define SET_SETTINGS "setSettings"
 #define SEND_MESSAGE "sendMessage"
+#define SEND_WALL_MESSAGE "sendWallMessage"
 #define GET_BINARY_DATA "getBinaryData"
 #define CAPTCHA_MESSAGE "captchaMessage"
 #define DELETE_FRIEND "deleteFriend"
@@ -119,6 +120,7 @@ xmlChar* get_req_class(xmlDocPtr reqXml);
 xmlChar* get_req_function(xmlDocPtr reqXml);
 int captcha_message(xmlDocPtr doc, xmlDocPtr reqXml);
 int http_get(const char* url, const char* proxy, const int port, char** header, gchar** body);
+int http_upload_photo(const char* url, const char* proxy, const int port, char** header, gchar** body, struct ProfileData *cp, char* file, char* file_name);
 int http_post(const char* url, const char* proxy, const int port, char* post_data, char** header, char** body, struct curl_slist** cookies);
 
 /**
@@ -131,7 +133,7 @@ int http_post(const char* url, const char* proxy, const int port, char* post_dat
  */
 int make_request(xmlDocPtr reqXml, xmlDocPtr doc, struct ProfileData *cp);
 int read_message(xmlDocPtr reqXml, char* remixmid, char* remixsid);
-gchar* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid);
+gchar* make_url(xmlDocPtr reqXml, char* remixmid, char* remixsid, struct ProfileData *cp);
 int get_settings(xmlDocPtr doc, const struct ProfileData *cp);
 
 /**
