@@ -57,6 +57,11 @@
 #define SET_PROFILE "setProfile"
 #define UPDATE_PROFILE "updateProfile"
 
+#define CLASS_PHOTOS "photos"
+#define GET_ALBUMS "getAlbums"
+#define GET_PHOTOS "getPhotos"
+#define UPLOAD_PHOTO "uploadPhoto"
+
 #define CLASS_FRIENDS "friends"
 #define GET_FRIENDS "getListFriends"
 #define UPDATE_FRIENDS "updateListFriends"
@@ -67,7 +72,10 @@
 #define GET_INBOX_MESSAGES "getInboxMessages"
 #define GET_OUTBOX_MESSAGES "getOutboxMessages"
 #define GET_NEW_MESSAGES "getNewInboxMessages"
+#define UPDATE_WALL_MESSAGES "updateWallMessages"
 #define READ_MESSAGE "readMessage"
+#define SEND_MESSAGE "sendMessage"
+#define SEND_WALL_MESSAGE "sendWallMessage"
 
 #define CLASS_MESSAGES "systemMessages"
 #define INFO_MESSAGE "infoMessage"
@@ -95,6 +103,7 @@
 #define DRV_MESS_DEL_CODE "413"
 #define DRV_MESS_READ_CODE "415"
 #define DRV_FRIEND_DEL_CODE "414"
+#define DRV_PHOTO_UPLOAD_CODE "420"
 
 /** Driver message text **/
 #define DRV_SETT_ERROR "Unable to save settings"
@@ -145,6 +154,9 @@
 #define DRV_FRIEND_DEL "Friend deleted"
 #define L10N_DRV_FRIEND_DEL _("Friend deleted")
 
+#define DRV_PHOTO_UPLOAD "Photo uploaded"
+#define L10N_DRV_PHOTO_UPLOAD _("Photo uploaded")
+
 /* Entity names */
 #define FIRST_NAME "FirstName"
 #define L10N_FIRST_NAME _("FirstName")
