@@ -20,100 +20,58 @@
  * Boston, MA  02110-1301  USA
  */
 
-#include "driver.h"
-#include "vkontakte.h"
-
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 
+#include "driver.h"
+#include "vkontakte.h"
+#include "profile.h"
+
+/*
+ * @brief The empty response XML string. Contains structure and main items
+ */
 const char* response_string = "\
 <TransitData>\
 <TargetID></TargetID>\
-<SourceID>vkontakte</SourceID>\
-<Content>\
-</Content>\
+<SourceID></SourceID>\
+<Content></Content>\
 </TransitData>";
-/**
-* Функция отправки данных драйвером
-*/
-static int vk_driver_send(xmlDocPtr request, xmlDocPtr* response, msa_module* driver_info);
 
-static int vk_driver_shutdown();
+/**
+ * @brief Function process requests to driver
+ */
+static error_type vk_driver_send(xmlDocPtr request, xmlDocPtr* response, const struct msa_module* info);
+
+static error_type vk_driver_shutdown(const struct msa_module*);
+
 /**
  * Module initialization. Prepare driverVK for work.
  *
  * @param d - msa_module, information for dispatcher
  * @return 0 on success or 1 otherwise.
  */
-extern int msa_module_init(msa_module* d)
+error_type msa_module_init(struct msa_module* d)
 {
 #ifdef TEST
-    g_debug("TEST = %d",TEST );
+    g_debug("TEST = %d", TEST);
 #endif
     g_debug("driver %s: init START", DRIVER_NAME);
 
+    struct ProfileData *cp = profile_create(DRIVER_ID);
+//dispatcher must free memory(struct msa_module) when application shutdown
     d->name = g_strdup(DRIVER_NAME);
+    d->id = g_strdup(cp->id);
+    //d->name = DRIVER_NAME;
     d->send = vk_driver_send;
     d->shutdown = vk_driver_shutdown;
     d->pic = g_strdup(VK_PIC);
-    
-    
-    set_events = d->set_events;
-    
+    //d->pic = VK_PIC;
 
-    GConfClient *client;
-    gchar* login;
-    gchar* password;
-    gint value;
-    gint time = 0;
-    int conf = 0;
+    d->state = NOT_CONF;
+    d->status = OFF;
 
-g_debug("before gconf");
-    g_type_init();
-    client = gconf_client_get_default ();
-g_debug("after gconf");
-
-    /* Get the initial value from GConf. */
-    gchar* path  = g_strconcat(PATH, STATUS, NULL);
-    value = gconf_client_get_int (client, path , NULL);
-    g_free(path);
-    
-    path = g_strconcat(PATH, LOGIN, NULL);
-    login = gconf_client_get_string (client, path, NULL);
-    g_free(path);
-    
-    path= g_strconcat(PATH, PASSWORD, NULL);
-    password = gconf_client_get_string (client, path, NULL);
-    g_free(path);
-    d->status = value;
-
-    path  = g_strconcat(PATH, AUTOUPDATE, NULL);
-    time = gconf_client_get_int (client, path , NULL);
-    g_free(path);
-
-	
-    if (value == 0) {
-        d->status = OFF;
-        d->state = CONF;
-    } else {
-        if ( login == NULL || password == NULL ) {
-            d->state = NOT_CONF;
-            d->status = OFF;
-        } else {
-            g_free(login);
-            g_free(password);
-            d->state = CONF;
-        }
-#ifndef TEST
-        g_print("TEST NOT DEFINE\n");
-        init_event_manager((int)time);
-#endif
-    }
-
-    g_object_unref((gpointer)client);
-    
     g_debug("driver %s: init END", DRIVER_NAME);
-    return 0;
+    return SUCCESS;
 }
 
 /**
@@ -123,7 +81,7 @@ g_debug("after gconf");
  * @param response - 
  * @return 0 on success or 1 otherwise.
  */
-static int vk_driver_send(xmlDocPtr request, xmlDocPtr* response, msa_module* info)
+static error_type vk_driver_send(xmlDocPtr request, xmlDocPtr* response, const struct msa_module* info)
 {
     xmlDocPtr reqXml = NULL, respXml = NULL;
     xmlDocPtr buffXml = NULL;
@@ -132,46 +90,39 @@ static int vk_driver_send(xmlDocPtr request, xmlDocPtr* response, msa_module* in
         return FAILURE;
     } else {
         g_debug("get proxy settings %s %d ", info->proxy, info->port);
-        info_proxy = info->proxy;
-        info_port = info->port;
     }
 
     g_debug("vk_driver_send: START");
 
     respXml = xmlNewDoc(BAD_CAST "1.0");
-    respXml->encoding = g_strdup(UTF8);
+    //respXml->encoding = UTF8;
 
 
     if(request == NULL) {
-        printf("Error! Can't read request\n");
+        g_warning("Error! Can't read request\n");
         return FAILURE;
     }
 
-    xmlXPathObject *Obj = NULL;
     xmlNodePtr node = NULL, node_request = NULL, node_response = NULL;
-    gchar* source;
+    xmlChar* source;
     
-    Obj = xpath("//TransitData/SourceID", request);
-    if(Obj != NULL) {
-        node = Obj->nodesetval->nodeTab[0];
+    node = xpath_get_node("//TransitData/SourceID", request);
+    if(node != NULL)
         source = xmlNodeGetContent(node);
-        xmlXPathFreeObject(Obj);
-    } else {
+    else
         return FAILURE;
-      }
-    
-    Obj = xpath("//TransitData/Content/Request", request);
-    if(Obj != NULL) {
-        node = Obj->nodesetval->nodeTab[0];
+
+    node = xpath_get_node("//TransitData/Content/Request", request);
+    if(node != NULL){
         node_request = xmlCopyNode(node, 1);
         xmlUnlinkNode(node_request);
         reqXml = xmlNewDoc(BAD_CAST "1.0");
-        reqXml->encoding = g_strdup(UTF8);
+        //reqXml->encoding = g_strdup(UTF8);
         xmlDocSetRootElement(reqXml, node_request);
-        xmlXPathFreeObject(Obj);
     } else {
         return FAILURE;
       }
+
     xmlFreeDoc(request);
     
     vk_req(reqXml, respXml, info);
@@ -185,25 +136,19 @@ static int vk_driver_send(xmlDocPtr request, xmlDocPtr* response, msa_module* in
     //buffXml = xmlNewDoc( BAD_CAST "1.0");
 
     buffXml = xmlParseDoc(BAD_CAST response_string);
-    buffXml->encoding = g_strdup(UTF8);
+    //buffXml->encoding = g_strdup(UTF8);
     
-    Obj = xpath("//TransitData/TargetID", buffXml);
-    if(Obj != NULL) {
-        node = Obj->nodesetval->nodeTab[0];
+    node = xpath_get_node("//TransitData/TargetID", buffXml);
+    if(node != NULL)
         xmlNodeSetContent(node, source);
-        xmlXPathFreeObject(Obj);
-    } else {
+    else
         return FAILURE;
-    }
 
-    Obj = xpath("//TransitData/Content", buffXml);
-    if(Obj != NULL){
-        node = Obj->nodesetval->nodeTab[0];
+    node = xpath_get_node("//TransitData/Content", buffXml);
+    if(node != NULL)
         xmlAddChild(node, node_response);
-        xmlXPathFreeObject(Obj);
-    } else {
+    else
         return FAILURE;
-    }
     
     *response = xmlCopyDoc(buffXml, 1);
     xmlFreeDoc(buffXml);
@@ -215,11 +160,27 @@ static int vk_driver_send(xmlDocPtr request, xmlDocPtr* response, msa_module* in
 /**
  * Shutdown driver
  *
- * @return 0
+ * @return SUCCESS
  */
-static int vk_driver_shutdown()
+static error_type vk_driver_shutdown(const struct msa_module *info)
 {
-//maybe remove cookie and logout from server
     g_debug("vk_driver_shutdown");
-    return 0;
+    struct ProfileData *cp = (struct ProfileData *)profile_get_by_id(info->id);
+    if (cp == NULL)
+        return FAILURE;
+    if (cp == profile_list) {
+        profile_list = profile_list->next;
+    }else{
+        /* try to find previous profile */
+        struct ProfileData *prev = (struct ProfileData *)profile_list;
+        while(prev->next != cp)
+        {
+            prev = prev->next;
+        }
+        prev->next = cp->next;
+    }
+    profile_remove(cp);
+
+//maybe remove cookie and logout from server
+    return SUCCESS;
 }
